@@ -1,6 +1,6 @@
 """Executes the application.
 """
-from .model_view_controller import Controller, Model, View
+from application.model_view_controller import Controller, Model, View
 
 if __name__ == "__main__":
     """Executes the application.
