@@ -6,13 +6,13 @@ from time import sleep
 import arrow  # datetime management
 import PySimpleGUI as sg  # GUI framework library
 
-from . import filemodel_func as backend
-from .classes.coin_cls import Coin
-from .classes.config_cls import Config
-from .classes.exchange_base_cls import Exchange
-from .classes.exchange_classes import *
-from .predefined_messages import PredefinedMessages
-from .screen_layout import Layout
+import application.filemodel_func as backend
+from application.classes.coin_cls import Coin
+from application.classes.config_cls import Config
+from application.classes.exchange_base_cls import Exchange
+from application.classes.exchange_classes import *
+from application.predefined_messages import PredefinedMessages
+from application.screen_layout import Layout
 
 
 class Controller():
